@@ -28,3 +28,7 @@ if (\PHP_VERSION_ID < 80000) {
 if (\PHP_VERSION_ID < 80100) {
     require __DIR__.'/Php81/bootstrap.php';
 }
+
+if (\PHP_VERSION_ID < 80200) {
+    require __DIR__.'/Php82/bootstrap.php';
+}
